/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.model.SensorDataFile;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;
import nl.cloudfarming.eventbus.BaseGuiEventProducer;

/**
 * Action which removes failed sensorDataFiles
 * @author Merijn Zengers
 */
public class RemoveSensorDataFileAction extends AbstractAction {

    private static final String ACTION_NAME = NbBundle.getMessage(SensorModule.class, "sensor.remove_sensor_data_file.name");
    private final EventProducer eventProducer = new EventProducer();

    public RemoveSensorDataFileAction() {
        super(ACTION_NAME);

    }

    @Override
    public void actionPerformed(ActionEvent e) {
        SensorService service = Lookup.getDefault().lookup(SensorService.class);

        assert (service != null);

        SensorFileLayer layer = Utilities.actionsGlobalContext().lookup(SensorFileLayer.class);

        SensorDataFile file = layer.getObject();

        assert (file != null);

        service.removeFailedSensorDataFileAndData(file);
        eventProducer.triggerEvent(SensorEventKey.SENSOR_FILE_REMOVED);

    }
        private class EventProducer extends BaseGuiEventProducer {

        public EventProducer() {
            super(SensorEventKey.class);
        }
    }
    
}
