/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import java.awt.event.ActionEvent;
import nl.cloudfarming.client.geoviewer.LayerAction;
import nl.cloudfarming.client.model.SensorRun;
import nl.cloudfarming.eventbus.BaseGuiEventProducer;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

/**
 * Action to remove unwanted sensor runs from the application
 * @author Merijn Zengers
 */
public class RemoveSensorRunAction extends LayerAction{
    private static final String ACTION_NAME = NbBundle.getMessage(SensorModule.class, "sensor.remove_sensor_run_.name");
    private final EventProducer eventProducer = new EventProducer();

    public RemoveSensorRunAction() {
        putValue(NAME, ACTION_NAME);

    }

    @Override
    public void actionPerformed(ActionEvent e) {
        SensorService service = Lookup.getDefault().lookup(SensorService.class);

        assert (service != null);

        SensorRunLayer layer = Utilities.actionsGlobalContext().lookup(SensorRunLayer.class);

        SensorRun run = layer.getObject();

        assert (run != null);

        service.removeSensorRun(run);
        eventProducer.triggerEvent(SensorEventKey.SENSOR_RUN_REMOVED);

    }
    
    private class EventProducer extends BaseGuiEventProducer {

        public EventProducer() {
            super(SensorEventKey.class);
        }
    }
}
