/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package nl.cloudfarming.client.sensor;

import com.vividsolutions.jts.geom.Point;
import java.awt.Color;
import nl.cloudfarming.client.geoviewer.LayerObject;
import nl.cloudfarming.client.geoviewer.LayerObjectAction;
import nl.cloudfarming.client.model.SensorData;
import nl.cloudfarming.client.util.GeometryUtil;
import org.geotools.geometry.jts.JTSFactoryFinder;

/**
 *
 * @author Timon Veenstra
 */
public class SensorDataLayerObject implements LayerObject<Point, SensorData> {

    private final Point geometry;
    private final SensorData sensorData;
    private final KeyAttribute keyAttribute;

    public SensorDataLayerObject(SensorData SensorData, KeyAttribute keyAttribute) {
        this.keyAttribute = keyAttribute;
        this.geometry = GeometryUtil.getPoint(JTSFactoryFinder.getGeometryFactory(null), SensorData.getLongitude(), SensorData.getLatitude());
        this.sensorData = SensorData;
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getGeometry() 
     * @return The Geometry of type MultiPolygon
     */
    @Override
    public Point getGeometry() {
        return this.geometry;
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getObject() 
     * @return The Object of type SensorData this LayerObject is representing
     */
    @Override
    public SensorData getObject() {
        return this.sensorData;
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getKey() 
     * @return Key as String
     */
    @Override
    public String getKey() {
        return Long.toString(this.sensorData.getId());
    }

    @Override
    public Double getKeyAttributeValue() {
        if (KeyAttribute.Vi1.equals(this.keyAttribute)) {
            return this.sensorData.getNdvi();
        } else {
            return this.sensorData.getWdvi();
        }
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getTooltipText() 
     * @return TooltipText as String
     */
    @Override
    public String getTooltipText() {
        return Long.toString(this.sensorData.getId());
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getId() 
     * @return The Id of the wrapped object
     */
    @Override
    public long getId() {
        return this.sensorData.getId();
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#save() 
     */
    @Override
    public void save() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    /**
     * @see nl.cloudfarming.client.geoviewer.LayerObject#getActions() 
     * @return Array with actions for this LayerObject
     */
    @Override
    public LayerObjectAction[] getActions() {
        return null;
    }

    public enum KeyAttribute {
        Vi1, Vi2;
    }
}
